@@ -39,7 +39,7 @@ impl CurlHttpTransport {
         let scheme = dsn.scheme();
 
         let mut handle = client;
-        let thread = TransportThread::new(move |envelope, mut rl| {
+        let thread = TransportThread::new(move |envelope, rl| {
             handle.reset();
             handle.url(&url).unwrap();
             handle.custom_request("POST").unwrap();
@@ -63,7 +63,6 @@ impl CurlHttpTransport {
             let mut headers = curl::easy::List::new();
             headers.append(&format!("X-Sentry-Auth: {}", auth)).unwrap();
             headers.append("Expect:").unwrap();
-            headers.append("Content-Type: application/json").unwrap();
             handle.http_headers(headers).unwrap();
             handle.upload(true).unwrap();
             handle.in_filesize(body.get_ref().len() as u64).unwrap();
@@ -120,7 +119,6 @@ impl CurlHttpTransport {
                     sentry_debug!("Failed to send envelope: {}", err);
                 }
             }
-            async move { rl }
         });
         Self { thread }
     }
